@@ -217,7 +217,8 @@ module SiSU_TeX_Pdf
       dob=@dob
       title=@md.title.full
       dob.tmp=dob.tmp.strip if dob.tmp
-      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2')
+      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2').
+        gsub(/#{Mx[:url_o]}|#{Mx[:url_c]}/,'')
       cont_ln=dob.tmp.dup
       cont_ln=cont_ln.gsub(/\\begin\{(monosp)\}(.+?)\\end\{\1\}/m,'\2').
         gsub(@@tex_pattern_margin_number,'')
@@ -235,7 +236,8 @@ module SiSU_TeX_Pdf
     def level4
       dob=@dob
       dob.tmp=dob.tmp.strip if dob.tmp
-      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2')
+      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2').
+        gsub(/#{Mx[:url_o]}|#{Mx[:url_c]}/,'')
       cont_ln=dob.tmp.dup
       cont_ln=cont_ln.gsub(/\\begin\{(monosp)\}(.+?)\\end\{\1\}/m,'\2').
         gsub(@@tex_pattern_margin_number,'').
@@ -259,7 +261,8 @@ module SiSU_TeX_Pdf
       dob=@dob
       # there is a problem here with creation of headers does not do what you would want it to header starts with a * and is not in bold work on \\@txt*, same for next section 2002w46
       dob.tmp=dob.tmp.strip if dob.tmp
-      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2')
+      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2').
+        gsub(/#{Mx[:url_o]}|#{Mx[:url_c]}/,'')
       cont_ln=dob.tmp.dup
       cont_ln=cont_ln.gsub(/\\begin\{(monosp)\}(.+?)\\end\{\1\}/m,'\2').
         gsub(@@tex_pattern_margin_number,'').
@@ -280,7 +283,8 @@ module SiSU_TeX_Pdf
       dob=@dob
       # there is a problem here with creation of headers does not do what you would want it to header starts with a * and is not in bold work on \\sub@txt*, same for previous section 2002w46
       dob.tmp=dob.tmp.strip if dob.tmp
-      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2')
+      dob.tmp=dob.tmp.gsub(/\\begin\{(bfseries|itshape)\}(.+?)\\end\{\1\}/m,'\2').
+        gsub(/#{Mx[:url_o]}|#{Mx[:url_c]}/,'')
       cont_ln=dob.tmp.dup
       cont_ln=cont_ln.gsub(/\\begin\{(monosp)\}(.+?)\\end\{\1\}/m,'\2').
         gsub(@@tex_pattern_margin_number,'').
